<?php 
class ApiSettingsController extends AppController{
    public $components = array('QuickSettings');
    public $check_force_login = false;
    public function beforeFilter()
    {
        parent::beforeFilter();
        $this->loadModel('SettingGroup');
        $this->loadModel('Setting');
    }
    
    public function admin_index()
    {
        $this->set('title_for_layout', __('Api Settings'));

        $this->QuickSettings->run($this, array("Api"), null);
    }
    
    public function all()
    {
        $settings = Cache::read('api.setting.all','api');
        if (!$settings){
            $setting_group = $this->SettingGroup->findByModuleId('MooApp');
            $setting_result = array();
            if($setting_group != null)
            {
                $settings = $this->Setting->find('all', array(
                    'conditions' => array(
                        'Setting.group_id' => $setting_group['SettingGroup']['id']
                    )
                ));

                if($settings != null)
                {
                    foreach($settings as $setting)
                    {
                        $name = $setting['Setting']['name'];
                        $value = Configure::read('MooApp.'.$name);
                        $setting_result[$name] = $value == null ? "" : $value;
                    }
                }
            }
            // Add for Subscription
            $isEnableSubcriptionApp = (Configure::read('Subscription.enable_subscription_packages')=="1")?true:false;
            $this->loadModel('PaymentGateway.Gateway');
            if (!$this->Gateway->hasAny(array('enabled' => 1))){
                $isEnableSubcriptionApp =  false;
            }
            $this->loadModel('Subscription.SubscriptionPackagePlan');
            if (!$this->SubscriptionPackagePlan->hasAny(array('deleted' => 0,'enable_plan' => 1))){
                $isEnableSubcriptionApp =  false;
            }
            
            $setting_result['moosite_enable_subscription_packages'] = $isEnableSubcriptionApp;
            //Add check Follow mode for activity feed
            $setting_result['moosite_enable_follow'] = (Configure::read('core.enable_follow')=="1")?true:false;
            $setting_result['moosite_enable_registration_code'] = (Configure::read('core.enable_registration_code')=="1" && trim(Configure::read('core.registration_code')))?true:false;

            $this->loadModel('Plugin');
            $plugins = $this->Plugin->find( 'all', array(
                'order' => 'id DESC'
            ));
            $setting_result['plugins'] = array();
            if($plugins != null)
            {
                foreach($plugins as $plugin)
                {
                    $enabled = (bool)$plugin['Plugin']['enabled'];
                    switch ($plugin['Plugin']['key'])
                    {
                        case "Sticker":
                            $enabled = (bool)Configure::read('Sticker.sticker_enabled');
                            break;
                    }
                    $setting_result['plugins'][] = array(
                        'name' => (string)$plugin['Plugin']['name'],
                        'key' => (string)$plugin['Plugin']['key'],
                        'enabled' => $enabled
                    );
                }
            }
            $setting_result = array_merge($setting_result,array('require_gender' => Configure::read('core.require_gender') ? true : false,
            		'show_gender_signup' => Configure::read('core.show_gender_signup') ? true : false,
            		'enable_unspecified_gender' => Configure::read('core.enable_unspecified_gender') ? true : false,
            		'birthday_require' => Configure::read('core.require_birthday') ? true : false,
            		'show_birthday_signup' => Configure::read('core.show_birthday_signup') ? true : false)
           	);
            
            $result = array(
                'message' => __d('api', 'success'),
                'setting' => $setting_result,
                '_serialize' => array('message', 'setting'),
            );

            Cache::write('api.setting.all',$result,'api');

        }else{
            $result =  $settings;
        }

        $this->set($result);
    }
}