<?php

/*
 * Copyright (c) SocialLOFT LLC
 * mooSocial - The Web 2.0 Social Network Software
 * @website: http://www.moosocial.com
 * @author: mooSocial
 * @license: https://moosocial.com/license/
 */

App::uses('Helper', 'View');

class ApiHelper extends Helper implements CakeEventListener {

    protected $_eventManager = null;

    public function getEventManager() {
        if (empty($this->_eventManager)) {
            $this->_eventManager = new CakeEventManager();
            $this->_eventManager->attach($this);
        }
        return $this->_eventManager;
    }

    public function implementedEvents() {
        return array();
    }

    public $helpers = array(
        'Html' => array('className' => 'MooHtml'),
        'Text',
        'Form' => array('className' => 'MooForm'),
        'Session',
        'Time' => array('className' => 'AppTime'),
        'Moo',
        'Menu.Menu',
        'MooGMap',
        'Text' => array('className' => 'MooText'),
        'MooPeople',
        'MooTranslate',
        'MooPhoto',
        'MooTime',
        'MooActivity',
        'MooPopup',
        'MooRequirejs',
        'Minify.Minify',
        'Storage.Storage',
        'Event.Event',
        'Photo.Photo',
        'Topic.Topic',
        'Blog.Blog',
        'Video.Video',
        'Group.Group'
    );
    public $actorHtml = array();

    public function renderAFeed($data, $likesExt = array(), $is_member = null, $admins_current = null, $uacos = array(), $admins = array()) {
        $event = new CakeEvent("ApiHelper.BeforeRenderApiFeed", $this, array(
            'data' => $data,
        ));
        $this->getEventManager()->dispatch($event);
        $result = $event->result['result'];
        if ($result)
            $feed = array_merge($feed, $result);

        $cuser = MooCore::getInstance()->getViewer();
        $utz = (!is_numeric(Configure::read('core.timezone')) ) ? Configure::read('core.timezone') : 'UTC';
        $uid = AuthComponent::user('id');
        $item_type = $data['Activity']['item_type'];
        $check_privacy_type = true;
        if ($data['Activity']['plugin']) {
            $options = array('plugin' => $data['Activity']['plugin']);
        } else {
            $options = array();
        }

        if ($item_type) {
            list($plugin, $name) = mooPluginSplit($item_type);
            $object = MooCore::getInstance()->getItemByType($item_type, $data['Activity']['item_id']);
        } else {
            $plugin = '';
            $name = '';
            $object = null;
        }

        $item_type_comment = empty($data['Activity']['item_type']) ? 'activity' : $data['Activity']['item_type'];
        $item_id = !empty($data['Activity']['item_id']) ? $data['Activity']['item_id'] : $data['Activity']['id'];

        if ($data['Activity']['params'] == 'item' && (isset($object[$name]['like_count']))) {
            $item_close_comment = $this->Moo->getCloseComment($item_id, $item_type_comment, $data);
            $close_item_type = $item_type_comment;
            $close_item_id = $item_id;
        } else {
            $item_close_comment = $this->Moo->getCloseComment($item_id, 'activity', $data);
            $close_item_type = 'activity';
            $close_item_id = $data['Activity']['id'];
        }

        if ($item_close_comment['status']) {
            $is_close_comment = 1;
        } else {
            $is_close_comment = 0;
        }
        if ($data['Activity']['user_id'] == $uid || ( $uid && $cuser['Role']['is_admin'] ) || (!empty($admins_current) && in_array($uid, $admins_current))) {
            $is_owner = 1;
        } else {
            $is_owner = 0;
        }

        $subject_type = MooCore::getInstance()->getSubjectType();
        $pin_type = '';
        if (strtolower($subject_type) != 'user') {
            $pin_type = 'activity';
            if ($subject_type) {
                $pin_type = 'item';
            }
        }

        if (strtolower($data['Activity']['type']) != 'user' && $data['Activity']['target_id']) {
            $target = MooCore::getInstance()->getItemByType($data['Activity']['type'], $data['Activity']['target_id']);
            list($plugin_target, $name_target) = mooPluginSplit($data['Activity']['type']);
            $show_subject = MooCore::getInstance()->checkShowSubjectActivity($target);
            if ($show_subject) {
                $plugin_helper = MooCore::getInstance()->getHelper($plugin_target . '_' . $plugin_target);
                if (method_exists($plugin_helper, 'checkPrivacyFeedHome')) {
                    $check_privacy_type = $plugin_helper->checkPrivacyFeedHome($target);
                }
            }
        }

        $items = array();
        $activityId = $data['Activity']['id'];
        $tagUser = $title = $target = $type = $objecttType = '';
        $actorHtml = '';


        $beforeRenderActorHtml = new CakeEvent("ApiHelper.beforeRenderActorHtml", $this, array(
            'activity' => $data['Activity'],
            'user' => $data['User']
        ));
        $this->getEventManager()->dispatch($beforeRenderActorHtml);
        if (!empty($beforeRenderActorHtml->result['result'])) :
            foreach ($beforeRenderActorHtml->result['result'] as $titleArray):
                $actorHtml .= $titleArray['titleHtml'];
            endforeach;
        endif;

        $actorHtml .= isset($data['User']['moo_href']) ? $this->Html->link($data['User']['name'], FULL_BASE_URL . $data['User']['moo_href']) : FULL_BASE_URL;

        $afterRenderActorHtml = new CakeEvent("ApiHelper.afterRenderActorHtml", $this, array(
            'activity' => $data['Activity'],
            'user' => $data['User']
        ));
        $this->getEventManager()->dispatch($afterRenderActorHtml);
        if (!empty($afterRenderActorHtml->result['result'])) :
            foreach ($afterRenderActorHtml->result['result'] as $titleArray):
                $actorHtml .= $titleArray['titleHtml'];
            endforeach;
        endif;

        switch ($data['Activity']['item_type']) {
            case 'user' :
                $type = $title = '';
                if ($data['Activity']['action'] == 'friend_add') :
                    $type = 'add';
                    $objecttType = 'User';

                    $ids = explode(',', $data['Activity']['items']);
                    $userModel = MooCore::getInstance()->getModel('User');
                    $userModel->cacheQueries = false;
                    $users = $userModel->find('all', array('conditions' => array('User.id' => $ids)));

//get status of feed
                    $friend_add1 = '%s';
                    $friend_add2 = __('%s and %s');
                    $friend_add3 = __('%s and %s');
                    $friend_add = '';
                    $friend_addHtml = '';


                    $name1 = isset($users[0]['User']) ? $this->Moo->getName($users[0]['User']) : '<a href="javascript:void(0);">' . __('deleted user') . '</a>';
                    $name2 = isset($users[1]['User']) ? $this->Moo->getName($users[1]['User']) : '<a href="javascript:void(0);">' . __('deleted user') . '</a>';
                    switch (count($users)) {
                        case 1:
                            if (isset($users[0]['User'])) {
                                $friend_add = sprintf($friend_add1, $users[0]['User']['name']);
                                $friend_addHtml = sprintf($friend_add1, $this->Html->link($users[0]['User']['name'], FULL_BASE_URL . $users[0]['User']['moo_href']));
                            } else {
                                $friend_add = sprintf($friend_add1, $name1);
                                $friend_addHtml = sprintf($friend_add1, $name1);
                            }
                            break;
                        case 2:
                            if (isset($users[0]['User']) && isset($users[1]['User'])) {
                                $friend_add = sprintf($friend_add2, $users[0]['User']['name'], $users[1]['User']['name']);
                                $friend_addHtml = sprintf($friend_add2, $this->Html->link($users[0]['User']['name'], FULL_BASE_URL . $users[0]['User']['moo_href']), $this->Html->link($users[1]['User']['name'], FULL_BASE_URL . $users[1]['User']['moo_href']));
                            } else {
                                $friend_add = sprintf($friend_add2, $name1, $name2);
                                $friend_addHtml = sprintf($friend_add2, $name1, $name2);
                            }
                            break;
                        case 3:
                        default :
                            if (isset($users[0]['User'])) {
                                $friend_add = sprintf($friend_add3, $users[0]['User']['name'], abs(count($users) - 1) . ' ' . __('others'));
                                $friend_addHtml = sprintf($friend_add3, $this->Html->link($users[0]['User']['name'], FULL_BASE_URL . $users[0]['User']['moo_href']), abs(count($users) - 1) . ' ' . __('others'));
                            } else {
                                //$friend_add = sprintf($friend_add3, $this->Html->link($name1, FULL_BASE_URL . $users[0]['User']['moo_href']), abs(count($users) - 1) . ' ' . __('others'));
                                $friend_add = sprintf($friend_add1, $name1);
                                $friend_addHtml = sprintf($friend_add1, $name1);
                            }
                            break;
                    }

                    $title = $data['User']['name'] . ' ' . __('is now friends with') . ' ' . $friend_add;
                    $titleHtml = $actorHtml . ' ' . __('is now friends with') . ' ' . $friend_addHtml;

//get Friend List display at feed
                    $userArrays = array();
                    foreach ($users as $user):
                        if (!empty($user)):

                            if (!empty($uid)):
                                $userStatus = '';
                                if ($this->MooPeople->sentFriendRequest($user['User']['id'])):
                                    $userStatus = __('Cancel Request');
                                elseif ($this->MooPeople->respondFriendRequest($user['User']['id'])):
                                    $userStatus = __('Respond to Friend Request');
                                elseif ($this->MooPeople->isFriend($user['User']['id'])):
                                    $userStatus = __('Remove');
                                elseif ($user['User']['id'] != $uid):
                                    $userStatus = __('Add');
                                endif;
                            endif;
                            $userArrays[] = array(
                                'url' => $user['User']['moo_href'],
                                'type' => $user['User']['moo_type'],
                                'id' => $user['User']['id'],
                                'image' => array(
                                    '50_square' => $this->Moo->getItemPhoto(array('User' => $user['User']), array('prefix' => '50_square'), array(), true),
                                    '100_square' => $this->Moo->getItemPhoto(array('User' => $user['User']), array('prefix' => '100_square'), array(), true),
                                    '200_square' => $this->Moo->getItemPhoto(array('User' => $user['User']), array('prefix' => '200_square'), array(), true),
                                    '600' => $this->Moo->getItemPhoto(array('User' => $user['User']), array('prefix' => '600'), array(), true),
                                    "type" => "Link",
                                    "mediaType" => "image/jpeg",
                                ),
                                'name' => $user['User']['name'],
                                'friendCount' => __n('%s friend', '%s friends', $user['User']['friend_count'], $user['User']['friend_count']),
                                'photoCount' => __n('%s photo', '%s photos', $user['User']['photo_count'], $user['User']['photo_count']),
                                'status' => $userStatus,
                            );

                        endif;
                    endforeach;


                endif;


//respond data
                $items = array(
                    'type' => $type,
                    'userList' => $userArrays,
                );
                break;
        }

        if (isset($data['ActivityComment'])) :
            $commentCount = count($data['ActivityComment']);
        endif;
        if (isset($data['PhotoComment'])) :
            $commentCount = count($data['PhotoComment']);
        endif;
        if (isset($data['ItemComment'])) :
            $commentCount = count($data['ItemComment']);
            if (isset($data['ItemCommentCount']))
                $commentCount = $data['ItemCommentCount'];
        endif;





        $hideLikeAndComment = false;
        if ($data['Activity']['params'] != 'no-comments') {
            if ((!($data['Activity']['item_type'] == 'Topic_Topic' && isset($object['Topic']) && $object['Topic']['locked']) ) || (!empty($cuser) && $cuser['Role']['is_admin'])) {
                if (!isset($is_member) || $is_member || $cuser['Role']['is_admin']) {
                    if ($check_privacy_type && ((isset($groupTypeItem) && $groupTypeItem['is_member']) || (!isset($groupTypeItem)) )) {
                        $hideLikeAndComment = false;
                    } else {
                        $hideLikeAndComment = true;
                    }
                } else {
                    $hideLikeAndComment = true;
                }
            } else {
                $hideLikeAndComment = true;
            }
        } else {
            $hideLikeAndComment = true;
        }

        $canClosedComment = $canDelete = false;
        if (( (!empty($admins_current) && in_array($uid, $admins_current)) || $data['Activity']['user_id'] == $uid || $cuser['Role']['is_admin'])) {
            $canDelete = true;
            $canClosedComment = true;
        }

        // Closed comment feature .
        $isClosedComment = false;
        $closedCommentText = '';
        if ($is_close_comment && !$is_owner) {
            $closedCommentText = __('%s turned off commenting for this post', $this->Moo->getName($item_close_comment['User']));
            $isClosedComment = true;
        } else if ($is_close_comment && $is_owner) {
            $closedCommentText = __('%s turned off commenting for this post. However, you and admin still allow you to do so.', $this->Moo->getName($item_close_comment['User']));
            $isClosedComment = true;
        }

        if ($is_close_comment) {
            $feedCommentStatus = '#open';
        } else {
            $feedCommentStatus = '#close';
        }

        $text_pin = '';
        $canPin = $show_pin = false;
        if ($pin_type) {
            if (( (!empty($admins) && in_array($uid, $admins)) || $cuser['Role']['is_admin'])) {
                $text_pin = __('Pin to top');
                $canPin = true;
                if ($pin_type == 'activity') {
                    if ($data['Activity']['activity_pin']) {
                        $text_pin = __('Unpin from top');
                    }
                } else {
                    if ($data['Activity']['pin']) {
                        $text_pin = __('Unpin from top');
                    }
                }
            }

            if ($pin_type == 'activity') {
                $show_pin = $data['Activity']['activity_pin'];
            } else {
                $show_pin = $data['Activity']['pin'];
            }
        }

        $feed['items'] = array(
            'action' => $data['Activity']['action'],
            'id' => $data['Activity']['id'],
            'modified' => $data['Activity']['modified'],
            'published' => $data['Activity']['created'],
            'modifiedTranslated' => $this->Moo->getTime($data['Activity']['modified'], Configure::read('core.date_format'), $utz),
            'publishedTranslated' => $this->Moo->getTime($data['Activity']['created'], Configure::read('core.date_format'), $utz),
            'hideLikeAndComment' => $hideLikeAndComment,
            'share' => $data['Activity']['privacy'] == PRIVACY_ME ? false : $data['Activity']['share'],
            'privacy' => $this->getPrivacy($data),
            'likeCount' => ($data['Activity']['params'] == 'item' && isset($object[$name]['like_count'])) ? $object[$name]['like_count'] : $data['Activity']['like_count'],
            'dislikeCount' => ($data['Activity']['params'] == 'item' && isset($object[$name]['dislike_count'])) ? $object[$name]['dislike_count'] : $data['Activity']['dislike_count'],
            'commentCount' => $commentCount,
            'actor' => $this->getUser($data['User']),
            'title' => $title,
            'titleHtml' => isset($titleHtml) ? $titleHtml : '',
            'type' => $type,
            'objects' => $items,
            'target' => $target,
            'isActivityView' => false,
            'hideFeedHeader' => false,
            'canDelete' => $canDelete,
            'isClosedComment' => $isClosedComment,
            'closedCommentText' => $closedCommentText,
            'canClosedComment' => $canClosedComment,
            'feedCommentStatus' => $feedCommentStatus,
            'showPin' => $show_pin,
            'textPin' => $text_pin,
            'canPin' => $canPin,
            'isPhotoFeed' => isset($data['PhotoComment'][0]) ? true : false,
        );
        $actionStr = $data['Activity']['action'] . "-end";
        if (strpos($actionStr, "_share-end") !== false && strpos($actionStr, "item_detail_share-end") === false) {
            $feed['items'] = array_merge($feed['items'], $this->exportActivityShare($data, $actorHtml));
        } else {
            $event = new CakeEvent("ApiHelper.renderAFeed." . $data['Activity']['action'], $this, array(
                'data' => $data,
                'objectPlugin' => $object,
                'actorHtml' => $actorHtml,
                'fullbaseUrl' => FULL_BASE_URL,
                'uacos' => $uacos
            ));
            $this->getEventManager()->dispatch($event);
            $result = $event->result['result'];
            if (!$result) {
                CakeLog::write('Api', 'Can not get an activity from calling event ' . "ApiHelper.renderAFeed." . $data['Activity']['action']);
            } else {
                $feed['items'] = array_merge($feed['items'], $result);
            }
        }

        $skipAction = array("wall_post_background");
        if (!in_array($data['Activity']['action'], $skipAction)) {
            list($tagUser, $content, $contentHtml) = $this->getContentAndTagUser($data);
            $feed['items']['objects'] = array_merge($feed['items']['objects'], array(
                'content' => $content,
                'contentHtml' => $contentHtml,
                'tagUser' => $tagUser,
            ));
        }

        $feed = $this->getViewerLikeOrDislike($feed, $data, $object, $name, $likesExt, $uid);
        $feed = $this->getFirstComment($feed, $data, $utz, $commentCount);


        $event = new CakeEvent("ApiHelper.AfterRenderApiFeed", $this, array(
            'data' => $data,
            'objectPlugin' => $object,
            'actorHtml' => $actorHtml,
            'fullbaseUrl' => FULL_BASE_URL,
        ));
        $this->getEventManager()->dispatch($event);
        $result = $event->result['result'];
        if ($result)
            $feed['items'] = array_merge($feed['items'], $result);

		$event = new CakeEvent("ApiHelper.AfterRenderApiFeedObject", $this, array(
			'data' => $data,
            'feed' => $feed
        ));
        $this->getEventManager()->dispatch($event);
		if(!empty($event->result['feed']))
		{
			$feed = $event->result['feed'];
		}
        return $feed;
    }

    public function afterRenderAFeed($data, $index) {
        $event = new CakeEvent("ApiHelper.afterRenderApiOneFeed", $this, array(
            'data' => $data,
            'index' => $index
        ));
        $this->getEventManager()->dispatch($event);
        if (empty($event->result['result'])) {
            return array();
        }
        $result = $event->result['result'];

        $feed['items'] = array(
            'action' => $result['type'],
            'modified' => date("Y-m-d H:i:s", strtotime($data['Activity']['modified'] . " - 1 second")),
            'hideLikeAndComment' => true,
            'share' => false,
            'privacy' => 1,
            'likeCount' => 0,
            'dislikeCount' => 0,
            'commentCount' => 0,
            'actor' => array(),
            'type' => $result['type'],
            'target' => array(),
            'isActivityView' => false,
            'canDelete' => false,
        );
        $feed['items'] = array_merge($feed['items'], $result);

        return $feed;
    }

    function getViewerLikeOrDislike($feed, $data, $object, $name, $likesExt, $uid) {
        $feed['items']['isViewerLiked'] = $feed['items']['isViewerDisliked'] = false;

        if ($data['Activity']['params'] == 'item' && (isset($object[$name]['like_count']))) {

            if (!empty($uid) && !empty($data['Likes'][$uid])) {
                $feed['items']['isViewerLiked'] = true;
            }

            if (!empty($uid) && isset($data['Likes'][$uid]) && $data['Likes'][$uid] == 0) {
                $feed['items']['isViewerDisliked'] = true;
            }
        } else {

            if (!empty($uid) && !empty($likesExt['activity_likes'][$data['Activity']['id']])) {
                $feed['items']['isViewerLiked'] = true;
            }

            if (!empty($uid) && isset($likesExt['activity_likes'][$data['Activity']['id']]) && $likesExt['activity_likes'][$data['Activity']['id']] == 0) {
                $feed['items']['isViewerDisliked'] = true;
            }
        }
        $feed['items']['isHideDislike'] = Configure::read('core.hide_dislike') ? true : false;
        return $feed;
    }

    function getFirstComment($feed, $data, $utz, $commentCount) {
        if (Configure::read('core.comment_sort_style') == COMMENT_CHRONOLOGICAL) {
            if (isset($data['PhotoComment'][0])) {
                $commentModel = MooCore::getInstance()->getModel('Comment');
                $target_id = $data['PhotoComment'][0]['Comment']['target_id'];
                $type = $data['PhotoComment'][0]['Comment']['type'];
                $comment = $commentModel->find('first', array('conditions' => array('Comment.target_id' => $target_id, 'Comment.type' => $type), 'order' => array('Comment.id DESC')));
                if (!empty($comment)) {
                    $feed = $this->getPhotoComment($feed, $comment, $utz);
                }
            }
            if (isset($data['ActivityComment'][0])) {
                $commentModel = MooCore::getInstance()->getModel('ActivityComment');
                $target_id = $data['ActivityComment'][0]['activity_id'];
                $type = 'Activity';
                $comment = $commentModel->find('first', array('conditions' => array('ActivityComment.activity_id' => $target_id), 'order' => array('ActivityComment.id DESC')));
                if (!empty($comment)) {
                    $feed = $this->getActivityComment($feed, $comment, $utz);
                }
            }

            if (isset($data['ItemComment'][0])) {
                $commentModel = MooCore::getInstance()->getModel('Comment');
                $target_id = $data['ItemComment'][0]['Comment']['target_id'];
                $type = $data['ItemComment'][0]['Comment']['type'];
                $comment = $commentModel->find('first', array('conditions' => array('Comment.target_id' => $target_id, 'Comment.type' => $type), 'order' => array('Comment.id DESC')));
                if (!empty($comment)) {
                    $feed = $this->getItemComment($feed, $comment, $utz);
                }
            }
        } else {
            if (isset($data['PhotoComment'][0])) {
                $feed = $this->getPhotoComment($feed, $data['PhotoComment'][0], $utz);
            }

            if (isset($data['ActivityComment'][0])) {
                $feed = $this->getActivityComment($feed, $data['ActivityComment'][0], $utz);
            }

            if (isset($data['ItemComment'][0])) {
                $feed = $this->getPhotoComment($feed, $data['ItemComment'][0], $utz);
            }
        }


        if (isset($feed['items']['comment']['user'])) {

            $afterRenderActorHtml = new CakeEvent("ApiHelper.afterRenderFirstCommentUserName", $this, array(
                'activity' => $data['Activity'],
                'user' => $feed['items']['comment']['user']
            ));

            $this->getEventManager()->dispatch($afterRenderActorHtml);
            if (!empty($afterRenderActorHtml->result['result'])) :
                foreach ($afterRenderActorHtml->result['result'] as $titleArray):
                    $feed['items']['comment']['user']['name'] .= $titleArray['titleHtml'];
                endforeach;
            endif;
        }
		
		//event afterRenderFirstComment
        if (isset($data['ItemComment'][0]) || isset($data['ActivityComment'][0]) || isset($data['PhotoComment'][0])) 
        {
            $comment_data = array();
            if(isset($data['PhotoComment'][0]))
            {
                $comment_data = $data['PhotoComment'][0];
            }
            else if(isset($data['ActivityComment'][0]))
            {
                $comment_data = $data['ActivityComment'][0];
            }
            else if(isset($data['ItemComment'][0]))
            {
                $comment_data = $data['ItemComment'][0];
            }
            $afterRenderFirstComment = new CakeEvent("ApiHelper.afterRenderFirstComment", $this, array(
                'data' => $comment_data,
                'data_json' => $feed['items']['comment']
            ));
            $this->getEventManager()->dispatch($afterRenderFirstComment);
            if(!empty($afterRenderFirstComment->result['result']) && !empty($feed['items']['comment'])) 
            {
                $result = $afterRenderFirstComment->result['result'];
                $feed['items']['comment'] = array_merge($feed['items']['comment'], $result);
            }
        }

        return $feed;
    }

    function convertToObject($type, $data, $that) {
        switch ($type) {
            case 'user':
            case 'blog':
            case 'album':
            case 'photo':
            case 'video':
            case 'topic':
            case 'group':
            case 'event':
                return array(
                    'url' => FULL_BASE_URL . $that->Html->url(array(
                        'plugin' => false,
                        'controller' => 'events',
                        'action' => 'view',
                        $data['Event']['id'],
                        seoUrl($data['Event']['title']),
                    )),
                    'title' => $data['Event']['moo_title'],
                    'private' => $data['Event']['type'],
                    'privateTranslated' => ($data['Event']['type'] == PRIVACY_PUBLIC) ? __('Public') : __('Private'),
                    'id' => $data['Event']['id'],
                    'image' => $that->Event->getImage($data, array()),
                    'from' => $data['Event']['from'],
                    'from_time' => $data['Event']['from_time'],
                    'to' => $data['Event']['to'],
                    'to_time' => $data['Event']['to_time'],
                    'timeTranslated' => $that->Time->event_format($data['Event']['from']) . ' ' . $data['Event']['from_time'] . ' - ' . $that->Time->event_format($data['Event']['to']) . ' ' . $data['Event']['to_time'],
                    'timezone' => $data['Event']['timezone'],
                    'location' => h($data['Event']['location']),
                    'address' => h($data['Event']['address']),
                    'category' => array(
                        'id' => $data['Event']['category_id'],
                        'name' => $data['Category']['name']
                    ),
                    'created_by' => $data['User']['id'],
                    'info' => $that->Moo->cleanHtml($that->Text->convert_clickable_links_for_hashtags($data['Event']['description'], Configure::read('Event.event_hashtag_enabled'))),
                );
            default:
                return array();
        }
    }

    function exportActivityShare($data, $actorHtml) {
        $objects = $target2 = $target = $tagUser = $title = $titleHtml = $activityMore = '';
        if (isset($data['Activity']['parent_id']) && $data['Activity']['parent_id']) {

            $activityModel = MooCore::getInstance()->getModel('Activity');
            $parentFeed = $activityModel->findById($data['Activity']['parent_id']);

            $title = __("shared %s's post", $parentFeed['User']['name']);
            $titleHtml = $actorHtml . ' ' . __("shared %s's post", $this->Html->link($parentFeed['User']['name'], FULL_BASE_URL . $parentFeed['User']['moo_href']));
            $target = array(
                'url' => $parentFeed['User']['moo_href'],
                'id' => $parentFeed['User']['id'],
                'name' => $parentFeed['User']['name'],
                'type' => 'User',
            );
            //$target = array_merge($target, $this->renderAFeed($parentFeed));
            $objects = $this->renderAFeed($parentFeed);
        }
        $type = 'share';
        if ($data['Activity']['target_id']) {
            $subject = MooCore::getInstance()->getItemByType($data['Activity']['type'], $data['Activity']['target_id']);
            list(, $name) = mooPluginSplit($data['Activity']['type']);
            $show_subject = MooCore::getInstance()->checkShowSubjectActivity($subject);

            if ($show_subject) {
                $type = 'share_user';
                $title .= ' > ' . $subject[$name]['moo_title'];
                //$titleHtml .= $actorHtml . ' > ' . $this->Html->link($subject[$name]['moo_title'], FULL_BASE_URL . $subject[$name]['moo_href']);
                $titleHtml .= ' > ' . $this->Html->link($subject[$name]['moo_title'], FULL_BASE_URL . $subject[$name]['moo_href']);
                $target2 = array(
                    'url' => $subject[$name]['moo_href'],
                    'id' => $subject[$name]['id'],
                    'name' => $subject[$name]['name'],
                    'type' => $subject[$name]['moo_plugin'] ? $subject[$name]['moo_plugin'] : $subject[$name]['moo_type'],
                );
                $target = array_merge($target, $target2);
                $activityMore = array(
                    'user_url' => FULL_BASE_URL . $parentFeed['User']['moo_href'],
                    'user_id' => $parentFeed['User']['id'],
                    'user_name' => $parentFeed['User']['name'],
                );
            }
        }
        $activityText = $data['Activity']['content'];
        $activityTextHtml = $data['Activity']['content'];
        if (!empty($data['UserTagging']['users_taggings'])) :
            $activityText = $data['Activity']['content'] . $this->MooPeople->getWithNotUrl($data['UserTagging']['id'], $data['UserTagging']['users_taggings'], false);
            $activityTextHtml = $data['Activity']['content'] . $this->MooPeople->with($data['UserTagging']['id'], $data['UserTagging']['users_taggings'], false);
            $tagUser = $this->MooPeople->getUserTagged($data['UserTagging']['users_taggings']);
        endif;



        $items = array(
            'type' => 'share',
            'title' => $title,
            'titleHtml' => $titleHtml,
            'objects' => $objects['items'],
            'content' => $activityText,
            'contentHtml' => $activityTextHtml,
            'tagUser' => $tagUser,
            'target' => $target,
        );
        if ($type == 'share_user')
            $items = array_merge($items, $activityMore);
        return $items;
    }

    function getActivityTarget($data, $actorHtml, $titlePrivate = false) {
        $title = $target = array();
        if ($data['Activity']['target_id']) {
            $subject = MooCore::getInstance()->getItemByType($data['Activity']['type'], $data['Activity']['target_id']);
            list(, $name) = mooPluginSplit($data['Activity']['type']);
            $show_subject = MooCore::getInstance()->checkShowSubjectActivity($subject);
            if ($show_subject) {
                if ($titlePrivate) {
                    $title = array(
                        'url' => $subject[$name]['moo_href'],
                        'title' => ' > ' . $subject[$name]['moo_title'],
                        'titleHtml' => ' > ' . $this->Html->link($subject[$name]['moo_title'], FULL_BASE_URL . $subject[$name]['moo_href']),
                    );
                } else {
                    $title = array(
                        'url' => $subject[$name]['moo_href'],
                        'title' => $data['User']['name'] . ' > ' . $subject[$name]['moo_title'],
                        'titleHtml' => $actorHtml . ' > ' . $this->Html->link($subject[$name]['moo_title'], FULL_BASE_URL . $subject[$name]['moo_href']),
                    );
                }
                $target = array(
                    'url' => $subject[$name]['moo_href'],
                    'id' => $subject[$name]['id'],
                    'name' => $subject[$name]['moo_title'],
                    'type' => $subject[$name]['moo_plugin'],
                );
            }
        }
        return array($title, $target);
    }

    function getImages($ids) {
        $photoModel = MooCore::getInstance()->getModel('Photo_Photo');
//$photos_total = $photoModel->find('all', array('conditions' => array('Photo.id' => $ids)));
        $photos = $photoModel->find('all', array('conditions' => array('Photo.id' => $ids),
                //'limit' => 4
        ));

        $imageArray = array();
        $photoSizes = explode('|', Configure::read('core.photo_image_sizes'));
        $i = 0;
        foreach ($photos as $photo) {
            $imageArray[$i]['idPhoto'] = $photo['Photo']['id'];
            $imageArray[$i]['idAlbum'] = !empty($photo['Album']) ? $photo['Album']['id'] : "";
            $imageArray[$i]['type'] = $photo['Photo']['type'];
            $imageArray[$i]['albumType'] = $photo['Photo']['album_type'] == '' ? 'Photo_Album' : $photo['Photo']['album_type'];
            $imageArray[$i]['albumTypeId'] = $photo['Photo']['album_type'] == '' ? $photo['Photo']['target_id'] : $photo['Photo']['album_type_id'];

            foreach ($photoSizes as $size) {
                $imageArray[$i][$size] = $this->Photo->getImage($photo, array('prefix' => $size));
            }
            $i++;
        }
        return $imageArray;
    }

    function getContentAndTagUser($data) {
        $content = $data['Activity']['content'];
        $contentHtml = nl2br($this->Text->autoLink($this->Moo->parseSmilies($data['Activity']['content']), array_merge(array('target' => '_blank', 'rel' => 'nofollow', 'escape' => false), array('no_replace_ssl' => 1))));
        $tagUser = array();
        if (!empty($data['UserTagging']['users_taggings'])) {
//$content = $data['Activity']['content'] . $this->MooPeople->getWithNotUrl($data['UserTagging']['id'], $data['UserTagging']['users_taggings'], false);
//$contentHtml = $data['Activity']['content'] . $this->MooPeople->with($data['UserTagging']['id'], $data['UserTagging']['users_taggings'], false);
            $content = array();
            $content = $data['Activity']['content'] . $this->MooPeople->getWithNotUrl($data['UserTagging']['id'], $data['UserTagging']['users_taggings'], false);
            $contentHtml = nl2br($this->Text->autoLink($this->Moo->parseSmilies($data['Activity']['content']), array_merge(array('target' => '_blank', 'rel' => 'nofollow', 'escape' => false), array('no_replace_ssl' => 1)))) . $this->MooPeople->with($data['UserTagging']['id'], $data['UserTagging']['users_taggings'], false);
            $tagUser = $this->MooPeople->getUserTagged($data['UserTagging']['users_taggings']);
        }
        return array($tagUser, $content, $contentHtml);
    }

    function getUser($data) {
        return array(
            'url' => FULL_BASE_URL . $data['moo_href'],
            'type' => $data['moo_type'],
            'id' => $data['id'],
            'image' => array(
                '50_square' => $this->Moo->getItemPhoto(array('User' => $data), array('prefix' => '50_square'), array(), true),
                '100_square' => $this->Moo->getItemPhoto(array('User' => $data), array('prefix' => '100_square'), array(), true),
                '200_square' => $this->Moo->getItemPhoto(array('User' => $data), array('prefix' => '200_square'), array(), true),
                '600' => $this->Moo->getItemPhoto(array('User' => $data), array('prefix' => '600'), array(), true),
                "type" => "Link",
                "mediaType" => "image/jpeg",
            ),
            'name' => $data['name'],
            'role_id' => $data['role_id'],
        );
    }

    function getPrivacy($data) {
        $privacy = "1";
        if (!$data['Activity']['target_id']):
            switch ($data['Activity']['privacy']) {
                case '1':
                    $privacy = "1";
                    break;
                case '2':
                    $privacy = "2";
                    break;
                case '3':
                    $privacy = "3";
                    break;
            }
            if (!empty($uid) && ($data['Activity']['user_id'] == $uid || $cuser['Role']['is_admin']) && $data['Activity']['action'] == 'wall_post'):

                $privacy = "1";
            else:
                $privacy = $data['Activity']['privacy'];
            endif;
        elseif (strtolower($data['Activity']['type']) == 'user'):

            $target = MooCore::getInstance()->getItemByType($data['Activity']['type'], $data['Activity']['target_id']);
            if ($data['Activity']['privacy'] == PRIVACY_FRIENDS) :
                $privacy = "2";
            else:
                $privacy = "1";
            endif;
        else:

            $target = MooCore::getInstance()->getItemByType($data['Activity']['type'], $data['Activity']['target_id']);
            list($plugin_target, $name_target) = mooPluginSplit($data['Activity']['type']);
            $show_subject = MooCore::getInstance()->checkShowSubjectActivity($target);
            if ($show_subject):

                $plugin_helper = MooCore::getInstance()->getHelper($plugin_target . '_' . $plugin_target);
                $is_public = true;
                if (method_exists($plugin_helper, 'isPublicFeedIcon')) {
                    $is_public = $plugin_helper->isPublicFeedIcon($target);
                }

                if (method_exists($plugin_helper, 'checkPrivacyFeedHome')) {
                    $check_privacy_type = $plugin_helper->checkPrivacyFeedHome($target);
                }
                if ($is_public):
                    $privacy = "1";
                else:
                    $privacy = "2";
                endif;
            endif;
        endif;
        return $privacy;
    }

    function getPhotoComment($feed, $comment, $utz) {
        if (!empty($comment)) {
            $feed['items']['comment'] = array(
                'id' => $comment['Comment']['id'],
                'target_id' => $comment['Comment']['target_id'],
                'type' => $comment['Comment']['type'],
                'message' => nl2br($this->Text->autoLink($this->Moo->parseSmilies($comment['Comment']['message']), array_merge(array('target' => '_blank', 'rel' => 'nofollow', 'escape' => false), array('no_replace_ssl' => 1)))),
                'created' => $comment['Comment']['created'],
                'createdTranslated' => $this->Moo->getTime($comment['Comment']['created'], Configure::read('core.date_format'), $utz),
                'count_reply' => $comment['Comment']['count_reply'],
            );
            if (!empty($comment['Comment']['thumbnail'])) {
                if ($this->Moo->isGifImage($this->Moo->getImageUrl($comment, array()))) :
                    $feed['items']['comment']['thumbnail'] = $this->Moo->getImageUrl($comment, array('class' => 'gif_image'));
                else:
                    $feed['items']['comment']['thumbnail'] = $this->Moo->getImageUrl($comment, array('prefix' => '200'));
                endif;
                //$feed['items']['comment']['thumbnail'] = $this->Moo->getImageUrl($data['PhotoComment'][$commentPosition], array('prefix' => '200'));
            }

            $feed['items']['comment']['user'] = $this->getUser($comment['User']);
        }
        return $feed;
    }

    function getActivityComment($feed, $comment, $utz) {
        if (!empty($comment)) {
            $userTmp = $this->getUser($comment['User']);
            if(isset($comment['ActivityComment'])) $comment = $comment['ActivityComment'];
            $feed['items']['comment'] = array(
                'id' => $comment['id'],
                'target_id' => $comment['activity_id'],
                'type' => 'Activity',
                'message' => nl2br($this->Text->autoLink($this->Moo->parseSmilies($comment['comment']), array_merge(array('target' => '_blank', 'rel' => 'nofollow', 'escape' => false), array('no_replace_ssl' => 1)))),
                'created' => $comment['created'],
                'createdTranslated' => $this->Moo->getTime($comment['created'], Configure::read('core.date_format'), $utz),
                'count_reply' => $comment['count_reply'],
            );
            if (!empty($comment['thumbnail'])) {
                if ($this->Moo->isGifImage($this->Moo->getImageUrl($comment, array()))) :
                    $feed['items']['comment']['thumbnail'] = $this->Moo->getImageUrl($comment, array('class' => 'gif_image'));
                else:
                    $feed['items']['comment']['thumbnail'] = $this->Moo->getImageUrl($comment, array('prefix' => '200'));
                endif;
                //$feed['items']['comment']['thumbnail'] = $this->Moo->getImageUrl($data['PhotoComment'][$commentPosition], array('prefix' => '200'));
            }

            $feed['items']['comment']['user'] = $userTmp;
        }
        return $feed;
    }

    function getItemComment($feed, $comment, $utz) {
        if (!empty($comment)) {
            $feed['items']['comment'] = array(
                'id' => $comment['Comment']['id'],
                'target_id' => $comment['Comment']['target_id'],
                'type' => $comment['Comment']['type'],
                'message' => nl2br($this->Text->autoLink($this->Moo->parseSmilies($comment['Comment']['message']), array_merge(array('target' => '_blank', 'rel' => 'nofollow', 'escape' => false), array('no_replace_ssl' => 1)))),
                'created' => $comment['Comment']['created'],
                'createdTranslated' => $this->Moo->getTime($comment['Comment']['created'], Configure::read('core.date_format'), $utz),
                'count_reply' => $comment['Comment']['count_reply'],
            );
            if (!empty($comment['Comment']['thumbnail'])) {
                if ($this->Moo->isGifImage($this->Moo->getImageUrl($comment, array()))) :
                    $feed['items']['comment']['thumbnail'] = $this->Moo->getImageUrl($comment, array('class' => 'gif_image'));
                else:
                    $feed['items']['comment']['thumbnail'] = $this->Moo->getImageUrl($comment, array('prefix' => '200'));
                endif;
                //$feed['items']['comment']['thumbnail'] = $this->Moo->getImageUrl($data['PhotoComment'][$commentPosition], array('prefix' => '200'));
            }

            $feed['items']['comment']['user'] = $this->getUser($comment['User']);
        }
        return $feed;
    }

}
