import React from 'react';
import _ from 'lodash';
import {Card, CardActions, CardHeader, CardMedia, CardTitle, CardText} from 'material-ui/Card';
import {GridList, GridTile} from 'material-ui/GridList';
import MuiThemeProvider from 'material-ui/styles/MuiThemeProvider';
import getMuiTheme from 'material-ui/styles/getMuiTheme';
import {List, ListItem} from 'material-ui/List';
import Avatar from 'material-ui/Avatar';
import Chip from 'material-ui/Chip';
import {pharse} from '../../utility/mooApp';
import RaisedButton from 'material-ui/RaisedButton';
import {FirstLoading} from "../utility/FirstLoading";

import ActivityItem from '../activity/Item.js';
import {isPhone} from '../../utility/MobileDetector';
import {initLoadMoreBehavior} from '../../utility/mooApp';
import ACForm from '../activity/ACForm';
import {LoadMore} from '../utility/LoadMoreContent';
import AppAction from '../../utility/AppAction';
import {isIOS} from "../../utility/MobileDetector";

//import SelectField from 'material-ui/SelectField';
import Select from '@material-ui/core/Select';
import EventActions from '../../data/actions/EventActions';
import NavigationMoreVert from 'material-ui/svg-icons/navigation/more-vert';
import NavigationChevronLeft from 'material-ui/svg-icons/navigation/chevron-left';

import LikeActions from '../../data/actions/LikeActions';
import ActionFavoriteBorder from 'material-ui/svg-icons/action/favorite-border';
import ActionFavorite from 'material-ui/svg-icons/action/favorite';

import IconButton from '@material-ui/core/IconButton';
import Menu from '@material-ui/core/Menu';
import MenuItem from '@material-ui/core/MenuItem';
import MoreVertIcon from '@material-ui/icons/MoreVert';
import Button from '@material-ui/core/Button';

const iconNotActive = getMuiTheme({
    svgIcon: {
        color: "#9b9b9b"
    }
});
const iconActive = getMuiTheme({
    svgIcon: {
        color: "#FB7923"
    }
});

class EventDetail extends React.Component {
    constructor(props) {
        super(props);
        this.handleClick = this.handleClick.bind(this);
        this.handleChange = this.handleChange.bind(this);
        this.handleBookmark = this.handleBookmark.bind(this);
        this.handleClickMenu = this.handleClickMenu.bind(this);
        this.handleCloseMenu = this.handleCloseMenu.bind(this);
        this.state = {value:window.myRSVP,showMore:false,height:"100px",overflow:"hidden",
            bookmark: ( _.has(window, "isViewerBookmark") && window.isViewerBookmark == true) ? true : false,
            anchorEl: null,
        };
    }
    componentWillMount(){
        this.props.viewEventDetail(window.eventId);
        this.props.getEventActivity(window.eventId,1);
        this.props.fetchMe();
        initLoadMoreBehavior(function(){
            this.props.fetchNextEventActivity(window.eventId);
        }.bind(this));
    }
    componentDidUpdate(prevProps, prevState) {
        setTimeout(function () {
            if(prevProps.activites.get('shouldCheck') == true) {
                prevProps.removeActivityByRefesh();
            }
        }, 1);
    }
    handleBookmark(action) {
        var object = "Event_Event";
        var id = window.eventId;
        switch (action) {
            case "add":
                LikeActions.doBookmark(id,object);
                break;
            case "remove" :
                LikeActions.doRemoveBookmark(id,object);
                break;
        }
        this.setState({
                bookmark: !this.state.bookmark
            });
    }
    handleShareFeed(share_type){
        console.log("openShareFeed",this.props.events.get('events'));
        //AppAction.openShareFeed(this.props.events.get('events'), share_type);
        AppAction.showShare(this.props.events.get('events'), share_type);
    }
    handleChange (event) { 
        var value = event.target.value;
        var id = window.eventId;
        if(value) {
            EventActions.submitRSVP(id,value);
        }
        this.setState({value:value});
    }
    handleShowMore() {
        if(!this.state.showMore) {
            this.setState({
                showMore: !this.state.showMore,
                height:"auto",
                overflow:"visible"
            });
        }
        else {
            this.setState({
                showMore: !this.state.showMore,
                height:"100px",
                overflow:"hidden"
            });
        }
    }
    handleClick(url) {
            window.location.href = url;
    }
    handleOpenLink(url) {
        console.log(url);
        AppAction.openExternalLink(url);
    }
    handleEditDetail() {
        AppAction.hideComment();
        var url = mooConfig.url.full + mooConfig.url.base + '/events/create/' + window.eventId;
        AppAction.openEditNotNewTab({"link":url});
    }
    handleClickMenu (event) {
        this.setState({ anchorEl: event.currentTarget });
    };
    handleCloseMenu () {
        this.setState({ anchorEl: null });
    };

    render() {
        var bookmarkButton,canDelete,canEdit,content,event,title,description,media,eventView,privacy,date,category,location,address,userName,attend,maybe,notAttend,awaiting,feed,rsvp,menu,canShare,canInvite,event_recurring,canDeleteFollowing,canDeleteRecurring,payment_type,payment_link;
        canDelete = canEdit = canInvite = canShare = menu = rsvp = feed = awaiting = notAttend = maybe = attend = userName = address = location = category = date = eventView  = media = description = title  = content = event_recurring = canDeleteFollowing = canDeleteRecurring = payment_type = payment_link = <div></div>;
        
        var mainStyle = {borderBottom:"1px solid #dfdfdf",padding:"10px 0"};
        var labelStyle = {display:"block",float:"left",width:"110px",fontSize:"13px",paddingLeft:"10px",fontFamily:"Roboto, sans-serif"};
        var textStyle = {fontSize:"13px",overflow:"hidden",fontFamily:"Roboto, sans-serif"};
        var headStyle = {fontSize:"15px",overflow:"hidden",fontFamily:"Roboto, sans-serif",margin:"10px 10px 0",fontWeight:"bold"};
        var showMore = {height:"100px",overflow:"hidden"};
        var showLess = {height:"auto",overflow:"visible"};
        var event_name = {padding:"20px 30px 10px 10px",color:"#000",fontSize:'20px',fontWeight:"bold",lineHeight:"20px"};
        
        if( this.props.events.get('isOpen') == true  ) { 
            event = this.props.events.get('events');
            if (_.has(event, "thumbnail.850")) {  
                media = <CardMedia style={{position:"relative"}}>
                    <div style={{backgroundImage:"url('"+_.get(event,"thumbnail.850")+"')",backgroundRepeat:"no-repeat",paddingBottom:"56.25%",display:"block",backgroundSize:"cover",backgroundPosition:"center center"}}></div>
                </CardMedia>;
            }
            
            bookmarkButton = <div style={{display: "inline-block"}} ></div>;
            if(_.has(window,"isViewerBookmark" )) {
                if(this.state.bookmark == true ) {
                    bookmarkButton = <MuiThemeProvider muiTheme={iconActive}>
                        <span  style={{height: "35px", padding: "0 0", textAlign: "center", flex: "1", color: "#5e5e5e", fontSize: "12px"}}>
                            <IconButton style={{height: "35px", padding: "0"}} ><ActionFavorite viewBox="0 -3 30 30" onClick={() => this.handleBookmark("remove")} ></ActionFavorite></IconButton>
                        </span>
                       </MuiThemeProvider>
                }
                else {
                    bookmarkButton = <MuiThemeProvider muiTheme={iconNotActive}>
                    <span style={{height: "35px", padding: "0 0", textAlign: "center", flex: "1", color: "#5e5e5e", fontSize: "12px"}}>
                        <IconButton style={{height: "35px", padding: "0"}} ><ActionFavoriteBorder viewBox="0 -3 30 30" onClick={() => this.handleBookmark("add")} ></ActionFavoriteBorder></IconButton>
                    </span>
                    </MuiThemeProvider>
                }
                event_name = {padding:"20px 70px 10px 10px",color:"#000",fontSize:'20px',fontWeight:"bold",lineHeight:"20px"};
            }
            
            if (_.has(window, "canInvite")) {
                canInvite = <MenuItem onClick={() => this.handleClick(mooConfig.url.base + '/events/invite/' + window.eventId )} >{pharse("inviteFriend")}</MenuItem>
            }
            if (_.has(window, "canEdit")) { 
                    canEdit = <MenuItem onClick={() => this.handleEditDetail()}  >{pharse("edit")}</MenuItem>;
            } 
            if (_.has(window, "canDelete")) { 
                canDelete = <MenuItem onClick={() => this.handleClick(mooConfig.url.base + '/events/do_delete/' + window.eventId )}  >{pharse("delete")}</MenuItem>;
                if (_.has(window, "isDeleteEventAdvanced")) { 
                    canDeleteFollowing = <MenuItem onClick={() => this.handleClick(mooConfig.url.base + '/advanced_events/do_delete_following/' + window.eventId + '?app_no_tab=1' )} > {pharse("delete_following_event")}</MenuItem>;
                    canDeleteRecurring = <MenuItem onClick={() => this.handleClick(mooConfig.url.base + '/advanced_events/do_delete_all_recurring/' + window.eventId + '?app_no_tab=1' )} > {pharse("delete_all_recurring_event")}</MenuItem>;
                }                    
            }


            if (_.has(window, "canShare")) {
                canShare = <MenuItem onClick={() => this.handleShareFeed()} >{pharse("shareEvent")}</MenuItem>
                {/*   
            canShare = <MenuItem
                    innerDivStyle = {{padding:"0px 0px 0px 52px"}}
                    primaryText={pharse("shareEvent")}
                    leftIcon={<NavigationChevronLeft></NavigationChevronLeft>}
                    menuItems={[
                      <MenuItem primaryText={pharse('myWall')} onClick={() => this.handleShareFeed('#me')}/>,
                      <MenuItem primaryText={pharse('friendWall')} onClick={() => this.handleShareFeed('#friend')}/>,
                      <MenuItem primaryText={pharse('groupWall')} onClick={() => this.handleShareFeed('#group')}/>,
                      <MenuItem primaryText={pharse('email')} onClick={() => this.handleShareFeed('#email')}/>,
                    ]}
                  /> */}
            }
            
            
            const { anchorEl } = this.state;
            
            menu = <div>
                <Button
                  aria-owns={anchorEl ? 'simple-menu' : undefined}
                  aria-haspopup="true"
                  onClick={this.handleClickMenu}
                  style={{display:"block",position:"absolute",right:"5px",top:"18px",minWidth:"0",padding:"0",minHeight:"30px"}}
                >
                  <MoreVertIcon />
                </Button>
                <Menu
                  id="simple-menu"
                  anchorEl={anchorEl}
                  open={Boolean(anchorEl)}
                  onClose={this.handleCloseMenu}
                >
                    {canInvite}
                    {canEdit}
                    {canDelete}
                    {canDeleteFollowing}
                    {canDeleteRecurring}
                    {canShare}
                    <MenuItem onClick={() => this.handleClick(mooConfig.url.base + '/reports/ajax_create/event_event/' + window.eventId )} >{pharse("reportEvent")}</MenuItem>
                </Menu>
            </div>
            
            if (_.has(event, "title")) {
            title = <div style={{position:"relative"}}>
                    <div style={event_name} dangerouslySetInnerHTML={{__html: event.title}}></div>
                    <div style={{display:"block",position:"absolute",right:"25px",top:"13px"}}>{bookmarkButton}</div>
                    {menu}
                </div>
            }
            if (_.has(event, "privacy")) {
                
                if(event.privacy == 1) {
                   privacy = <div style={mainStyle}><div style={labelStyle}>{pharse("privacy")}:</div><div style={textStyle}>{pharse("public")}</div></div>;
                }
                else {
                   privacy = <div style={mainStyle}><div style={labelStyle}>{pharse("privacy")}:</div><div style={textStyle}>{pharse("private")}</div></div>;
                }
            }
            if (_.has(event, "fromTime")) {
                date = <div style={mainStyle}><div style={labelStyle}>{pharse("time")}:</div><div style={textStyle}>{event.fromTime} - {event.toTime}</div></div>;
            }
            if (_.has(event, "event_recurring")) {
                event_recurring = <div style={mainStyle}><div style={labelStyle}>{pharse("event_recurring")}:</div><div style={textStyle}>{event.event_recurring}</div></div>;
            }
            if (_.has(event, "payment_type")) {
                if(event.payment_type == "paid") {
                    payment_type = <div style={mainStyle}><div style={labelStyle}>{pharse("event_payment")}:</div><div style={textStyle}>{pharse("event_payment_paid")}</div></div>;
                    if (_.has(event, "link_payment")) {
                        payment_link = <div style={mainStyle}><div style={labelStyle}>{pharse("event_payment_url_paid")}:</div><div style={textStyle}><a style={{display:"inline-block",color:"#247BBA",marginLeft:"5px"}} onClick={() => this.handleOpenLink(event.link_payment)} >{event.link_payment_label}</a></div></div>;
                    }
                }else{
                    payment_type = <div style={mainStyle}><div style={labelStyle}>{pharse("event_payment")}:</div><div style={textStyle}>{pharse("event_payment_free")}</div></div>;
                }
            }
            
            if (_.has(event, "location")) {
                location = <div style={mainStyle}><div style={labelStyle}>{pharse("location")}:</div><div style={textStyle}>{event.location}</div></div>;
            }
            if (_.has(event, "address")) {
                address = <div style={mainStyle}><div style={labelStyle}>{pharse("address")}:</div><div style={textStyle}>{event.address}<a style={{display:"inline-block",color:"#247BBA",marginLeft:"5px"}} onClick={() => this.handleOpenLink('https://maps.google.com/maps?q='+encodeURI(event.address) )}  >({pharse("viewMap")})</a></div></div>;
            }
            if (_.has(event, "categoryName")) {
                category = <div style={mainStyle}><div style={labelStyle}>{pharse("category")}:</div><div style={textStyle}>{event.categoryName}</div></div>;
            }
            if (_.has(event, "createName")) {
                userName = <div style={mainStyle}><div style={labelStyle}>{pharse("userName")}:</div><div style={textStyle} dangerouslySetInnerHTML={{__html: event.createName}}></div></div>;
            }
            if (_.has(event, "description")) {
                description = <div style={{}}><div style={headStyle}>{pharse("des")}:</div>
                        <div className="post-body" style={{padding:"10px 10px 10px ",fontSize:"15px",lineHeight:"1.5"}} dangerouslySetInnerHTML={{__html: event.description}}></div></div>
            }
            if (_.has(window, "attendUser")) {
                var user = window.attendUser;
                var arrayUser = [];
                //var titleTmp = pharse('attendTitle').replace('%s', Object.keys(user).length);
                var titleTmp = pharse('attendTitle');
                Object.keys(user).forEach(function(key) {
                    arrayUser.push(<Chip onClick={() => this.handleClick(user[key].url)} labelStyle={{overflow: "hidden",textOverflow: "ellipsis",maxWidth: "200px"}} key={user[key].name+"-1"} style={{backgroundColor:"#e9e9eb",display:"inline-flex",margin:"4px"}} >
                                <Avatar src={user[key].avatar} />
                               <div style={{display:"inline-block"}} dangerouslySetInnerHTML={{__html: user[key].name }} ></div>
                              </Chip>
                      );
                },this);
                
                attend = <div style={{borderTop:"1px solid #dfdfdf"}}><div style={headStyle}>{titleTmp}</div>
                    <div style={{padding:"10px 10px 10px ",fontSize:"13px",lineHeight:"1.5"}}>{arrayUser}</div></div>
            }
            if (_.has(window, "maybeUser")) {
                var user = window.maybeUser;
                var arrayUser = [];
                //var titleTmp = pharse('maybeTitle').replace('%s', Object.keys(user).length);
                var titleTmp = pharse('maybeTitle');
                Object.keys(user).forEach(function(key) {
                    arrayUser.push(<Chip onClick={() => this.handleClick(user[key].url)} labelStyle={{overflow: "hidden",textOverflow: "ellipsis",maxWidth: "200px"}} key={user[key].name+"-1"} style={{backgroundColor:"#e9e9eb",display:"inline-flex",margin:"4px"}} >
                                <Avatar src={user[key].avatar} />
                                <div style={{display:"inline-block"}} dangerouslySetInnerHTML={{__html: user[key].name }} ></div>
                              </Chip>
                      );
                },this);
                
                maybe = <div style={{borderTop:"1px solid #dfdfdf"}}><div style={headStyle}>{titleTmp}</div>
                    <div style={{padding:"10px 10px 10px ",fontSize:"13px",lineHeight:"1.5"}}>{arrayUser}</div></div>
            }
            if (_.has(window, "notAttendUser")) {
                var user = window.notAttendUser;
                var arrayUser = [];
                //var titleTmp = pharse('notAttendTitle').replace('%s', Object.keys(user).length);
                var titleTmp = pharse('notAttendTitle');
                Object.keys(user).forEach(function(key) {
                    arrayUser.push(<Chip onClick={() => this.handleClick(user[key].url)} labelStyle={{overflow: "hidden",textOverflow: "ellipsis",maxWidth: "200px"}} key={user[key].name+"-1"} style={{backgroundColor:"#e9e9eb",display:"inline-flex",margin:"4px"}} >
                                <Avatar src={user[key].avatar} />
                                <div style={{display:"inline-block"}} dangerouslySetInnerHTML={{__html: user[key].name }} ></div>
                              </Chip>
                      );
                },this);
                
                notAttend = <div style={{borderTop:"1px solid #dfdfdf"}}><div style={headStyle}>{titleTmp}</div>
                    <div style={{padding:"10px 10px 10px ",fontSize:"13px",lineHeight:"1.5"}}>{arrayUser}</div></div>
            }
            if (_.has(window, "awaitingUser")) {
                var user = window.awaitingUser;
                var arrayUser = [];
                //var titleTmp = pharse('awaitingTitle').replace('%s', Object.keys(user).length);
                var titleTmp = pharse('awaitingTitle');
                Object.keys(user).forEach(function(key) {
                    arrayUser.push(<Chip onClick={() => this.handleClick(user[key].url)} labelStyle={{overflow: "hidden",textOverflow: "ellipsis",maxWidth: "200px"}} key={user[key].name+"-1"} style={{backgroundColor:"#e9e9eb",display:"inline-flex",margin:"4px"}} >
                                <Avatar src={user[key].avatar} />
                                <div style={{display:"inline-block"}} dangerouslySetInnerHTML={{__html: user[key].name }} ></div>
                              </Chip>
                      );
                },this);
                
                awaiting = <div style={{borderTop:"1px solid #dfdfdf"}}><div style={headStyle}>{titleTmp}</div>
                    <div style={{padding:"10px 10px 10px ",fontSize:"13px",lineHeight:"1.5"}}>{arrayUser}</div></div>
            }
            
            rsvp = <div><div style={headStyle}>{pharse("yourRSVP")}</div>
                <Select
                value={this.state.value}
                onChange={this.handleChange}
                style={{width:"150px",marginLeft:"10px"}}
              >
                <MenuItem value={1} >{pharse("yes")}</MenuItem>
                <MenuItem value={2} >{pharse("no")}</MenuItem>
                <MenuItem value={3} >{pharse("maybe")}</MenuItem>
                </Select>
                </div>
            
            //console.log(this.props.activites);
            feed = <EventFeed {...this.props} isPhone={isPhone()} ></EventFeed>;
                
            eventView = <div style={{margin:"-8px"}} >
                <Card style={{boxShadow:"none"}} >{media}{title}{rsvp}</Card>
                <div style={{background:"#fff",paddingBottom:"10px"}}>
                    <div style={{height:this.state.height,overflow:this.state.overflow}} >
                        <Card style={{boxShadow:"none"}} >{privacy}{date}{payment_type}{payment_link}{event_recurring}{location}{address}{category}{userName}{description}{attend}{maybe}{notAttend}{awaiting}</Card>
                    </div>
                    <div onClick={() => this.handleShowMore()} style={{margin:"10px auto",textAlign:"center"}} ><RaisedButton buttonStyle={{height:"auto"}} labelStyle={{textTransform:"uppercase"}} label={this.state.showMore ? pharse('showLess'): pharse('showMore')  } /></div>
                </div>
                {feed}
            </div>;
        
        }
        else {
            content = <FirstLoading></FirstLoading>;
        }
        
        return <MuiThemeProvider ><div>{content}{eventView}</div></MuiThemeProvider>;

    }
}
class EventFeed extends React.Component {
     constructor(props) {
        super(props);
    }

    render() {
            if(this.props.activites.get('records').count() > 0 ){
                var items = [];
                var isPhone = this.props.isPhone;

                var isFetching = this.props.activites.get('isFetching') ? true : false ;  
                var process = <LoadMore isFetching={isFetching} ></LoadMore>;

                this.props.activites.get('records').forEach(function(item){
                    items.push(<ActivityItem {...item} key={item.id} isPhone={isPhone} likes={this.props.likes} reactions={this.props.reactions} singleComment={true} page="events.view" />);
                    items.push(<div key={'a'+item.id} style={{height:'7px'}}/>);
                }.bind(this));

                return <MuiThemeProvider >
                    <div style={{padding:"8px 0"}}>
                        <div style={{paddingBottom:"0"}} ><ACForm {...this.props} target_id={window.eventId} type={"Event_Event"} /><div style={{height:'7px'}}/>{items}{process}</div>
                   </div>
                </MuiThemeProvider>;
            }else {
                return <MuiThemeProvider >
                        <div style={{padding:"8px 0"}}>
                            <ACForm target_id={window.eventId} type={"Event_Event"} {...this.props} />
                            <div style={{marginTop:"10px",background:"#fff",padding:"10px",textAlign:"center",fontFamily:"Roboto, sans-serif"}} >{pharse('notFound')}</div>
                        </div>
                        </MuiThemeProvider>;
            }  
        
    }
}
function EventViewContent(props) {
    return <EventDetail {...props} />
}

export default EventViewContent;
